PACKAGE_NAME  = 'ftsa-tjpb'
IMAGE_NAME    = 'testetjpb/ftsa-tjpb-image'
IMAGE_VERSION = '2.6.1'
VERSION       = '2.6.1'
TEST_PYPI     = False
DEPENDENCIES  = [
    'robotframework',
    'allure-python-commons',
    'allure-pytest',
    'allure-behave',
    'allure-robotframework',
    'robotframework-pabot',
    'robotframework-seleniumlibrary',
    'robotframework-appiumlibrary',
    'robotframework-faker',
    'robotframework-datadriver',
    'robotframework-databaselibrary',
    'robotframework-SikuliLibrary',
    'robotframework-requests',
    'robotframework-jsonlibrary',
    'robotframework-sshlibrary',
    'robotframework-pdf2textlibrary',
    'pyautogui',
    'selenium',
    'webdrivermanager',
    'opencv-python',
    'jproperties',
    'requests',
    'jsonpath_rw',
    'jsonpath_rw_ext',
    'pandas',
    'numpy',
    'PyMySQL',
    'psycopg2-binary',
    'cx_Oracle',
    'ftsa-tjpb-core'
]